@@ -25,9 +25,9 @@ from persistent.interfaces import IPersistent
 from transaction.interfaces import ITransactionManager
 from ZODB.interfaces import IConnection
 from zope.app.appsetup.interfaces import IDatabaseOpenedWithRootEvent
+from zope.component.interfaces import ISite
 from zope.container.interfaces import IObjectAddedEvent, IObjectRemovedEvent
 from zope.intid.interfaces import IIntIds
-from zope.location.interfaces import ISite
 
 # import local interfaces
 from ztfy.scheduler.interfaces import IScheduledTaskEvent, IUnscheduledTaskEvent
